=== modified file 'bzrlib/log.py'
--- bzrlib/log.py	2009-01-29 12:24:29 +0000
+++ bzrlib/log.py	2009-02-05 03:30:36 +0000
@@ -946,6 +946,7 @@
                             self.show_timezone, date_fmt="%Y-%m-%d",
                             show_offset=False),
                 tags, is_merge))
+        self.show_properties(revision.rev, indent+offset)
         if self.show_ids:
             to_file.write(indent + offset + 'revision-id:%s\n'
                           % (revision.rev.revision_id,))

=== modified file 'bzrlib/tests/test_log.py'
--- bzrlib/tests/test_log.py	2009-01-29 06:18:25 +0000
+++ bzrlib/tests/test_log.py	2009-02-05 03:30:36 +0000
@@ -735,6 +735,41 @@
 ''',
                                  sio.getvalue())
 
+    def test_properties_in_short_log(self):
+        """Log includes the custom properties returned by the registered 
+        handlers.
+        """
+        wt = self.make_branch_and_tree('.')
+        b = wt.branch
+        self.build_tree(['a'])
+        wt.add('a')
+        b.nick = 'test_properties_in_short_log'
+        wt.commit(message='add a',
+                  timestamp=1132711707,
+                  timezone=36000,
+                  committer='Lorem Ipsum <test@example.com>',
+                  author='John Doe <jdoe@example.com>')
+        sio = StringIO()
+        formatter = log.ShortLogFormatter(to_file=sio)
+        try:
+            def trivial_custom_prop_handler(revision):
+                return {'test_prop':'test_value'}
+
+            log.properties_handler_registry.register(
+                'trivial_custom_prop_handler',
+                trivial_custom_prop_handler)
+            log.show_log(b, formatter)
+        finally:
+            log.properties_handler_registry.remove(
+                'trivial_custom_prop_handler')
+            self.assertEqualDiff('''\
+    1 John Doe	2005-11-23
+      test_prop: test_value
+      add a
+
+''',
+                                 sio.getvalue())
+
     def test_error_in_properties_handler(self):
         """Log includes the custom properties returned by the registered 
         handlers.

